﻿# Script to provision a Hadoop Cluster on Azure
# This script is provided by Clounce and can be freely distributed
# If you find this script useful, we would appreciate any donation and mention.  Thanks!

$myPrefix = "clounce"
#$credentials = $null
$clusterName = $myPrefix + "cluster"
$clusterNodes = 2
$clusterVersion = "3.3"
$resourceGroupName = $myPrefix + "rg"
$storageAccountName = $myPrefix + "sa"
$storageContainerName= $myPrefix + "cnt"
$location = "West Europe"
$subscriptionName = "Azure Pass"

Login-AzureRmAccount
Select-AzureRmSubscription -SubscriptionName $subscriptionName

# Create resource group
New-AzureRmResourceGroup -name $resourceGroupName -Location $location -Force

# Create storage account
if (!(Test-AzureName -Storage $storageAccountName))
{
 New-AzureRmStorageAccount -ResourceGroupName $resourceGroupName -Name $storageAccountName -Location $location -Type Standard_RAGRS
}

# Get storage key
$storageAccountKey = Get-AzureRmStorageAccountKey -ResourceGroupName $resourceGroupName -Name $storageAccountName |  %{ $_.Key1 }

# Create a storage context object
$storageContext = New-AzureStorageContext -StorageAccountName $storageAccountName -StorageAccountKey $storageAccountKey  

# Create a Blob storage container
$blobContainer = Get-AzureStorageContainer -Name $storageContainerName -Context $storageContext -Verbose:$false -ErrorAction SilentlyContinue
if($blobContainer -eq $null)
{
    New-AzureStorageContainer -Name $storageContainerName -Context $storageContext
}

if ($credentials -eq $null) 
{
    # Get user credentials to use when provisioning the cluster.
    Write-Verbose "Prompt user for ssh credentials to set during provisioning."
    $credentials = Get-Credential
    Write-Verbose "Use these credentials to login to the cluster via ssh when the script is complete."
} 

# Create a new HDInsight cluster
New-AzureRmHDInsightCluster -ResourceGroupName $resourceGroupName `
    -ClusterName $clusterName `
    -Location $location `
    -DefaultStorageAccountName "$storageAccountName.blob.core.windows.net" `
    -DefaultStorageAccountKey $storageAccountKey `
    -DefaultStorageContainer $storageContainerName  `
    -ClusterType Hadoop `
    -OSType Linux `
    -Version $clusterVersion `
    -ClusterSizeInNodes $clusterNodes `
    -SshCredential $credentials 

# Display cluster details
Get-AzureRmHDInsightCluster -ClusterName $clusterName

# To connect using secure ssh use
# ssh HttpEndpoint but add -ssh after the hostname

# To remove cluster
# Remove-AzureRmHDInsightCluster -ClusterName $clusterName
